@@ -1,37 +1,42 @@
 $VAR1 = {
-          'version' => '0.75',
+          'scriptAlias' => 'cgi-bin',
+          'admin' => {
+                       'password' => 'testpass',
+                       'firstname' => 'Dirk',
+                       'name' => 'Lindner',
+                       'email' => 'dirk.lze@gmail.com'
+                     },
           'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
           'language' => 'en',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'floodtime' => 10,
           'config' => '/var/www/cgi-bin/config/settings.pl',
-          'database' => {
-                          'CurrentDb' => 'LZE',
-                          'name' => 'LZE',
-                          'host' => 'localhost',
-                          'CurrentPass' => 'keinz',
-                          'CurrentUser' => 'root',
-                          'password' => 'keinz',
-                          'CurrentHost' => 'localhost',
-                          'user' => 'root'
-                        },
+          'version' => '0.76',
           'cgi' => {
                      'cookiePath' => '/',
-                     'title' => 'MySQL::Admin',
                      'alias' => 'cgi-bin',
                      'serverName' => 'http://localhost',
-                     'style' => 'mysql',
-                     'DocumentRoot' => '/var/www/htdocs',
+                     'title' => 'MySQL::Admin',
+                     'bin' => '/var/www/cgi-bin',
                      'expires' => '+1y',
-                     'bin' => '/var/www/cgi-bin'
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'style' => 'mysql'
                    },
-          'admin' => {
-                       'name' => 'Lindner',
-                       'email' => 'dirk.lze@gmail.com',
-                       'firstname' => 'Dirk',
-                       'password' => 'testpass'
+          'files' => {
+                       'chmod' => '0755',
+                       'group' => 'www-data',
+                       'owner' => 'www-data'
                      },
-          'scriptAlias' => 'cgi-bin',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'floodtime' => 10
+          'database' => {
+                          'password' => 'keinz',
+                          'CurrentHost' => 'localhost',
+                          'name' => 'LZE',
+                          'CurrentPass' => 'keinz',
+                          'CurrentDb' => 'LZE',
+                          'CurrentUser' => 'root',
+                          'user' => 'root',
+                          'host' => 'localhost'
+                        }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
