@@ -12,6 +12,11 @@ function alert(txt){
 	  hide('popup');
 	});
 }
+
+window.onerror = logError;
+function logError(message, file, line){
+	 console.log("Message: "+message+"file: "+file+"line: "+line);
+}
 function confirm2(txt,sub,arg,arg2,arg3){
 	visible('popup');
 	var sleep = true;
@@ -130,12 +135,6 @@ function loadPage(inXml,inXsl,outId,tabId,title){
 	disableOutputEscaping('content');
 
 }
-
-window.onerror = logError;
-function logError(message, file, line){
-         alert("Message: "+message+"file: "+file+"line: "+line);
-}
-
 function markInput(bool){
        var body  = document.getElementsByTagName("body")[0];
        var node = body.getElementsByTagName("input");
@@ -229,41 +228,71 @@ function closePopup(){
 }
 var currentId, currentTxt;
 var act ='save';
-function submitForm(node,tabId,tabTitle){
+function submitForm(node,tabId,tabTitle,bHistory,method){
+  	bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
+	method   = typeof method   !== 'undefined' ? method   : 'POST';
+
 	if(checkForm(node)){
-	  var url = "../cgi-bin/mysql.pl?";
+	  var url = "../%ALIAS%/mysql.pl?";
+	  var formData = new FormData();
 	  for(var i =0; i < node.elements.length;i++){
 	    if(node.elements[i].type == 'checkbox' || node.elements[i].type == 'radio'){
-		    if(node.elements[i].checked)
-			url += node.elements[i].name+"="+encodeURIComponent(node.elements[i].value)+"&"; 
+		    if(node.elements[i].checked){
+		      if(method == 'POST')
+			formData.append(node.elements[i].name,node.elements[i].value);
+		      else
+			url += node.elements[i].name+"="+encodeURIComponent(node.elements[i].value)+"&";
+		    }
 	    }else if(node.elements[i].name == 'submit'){
-	      url += node.elements[i].name+"="+encodeURIComponent(act)+"&";
+	       if(method == 'POST')
+		  formData.append(node.elements[i].name,act);
+	       else
+		  url += node.elements[i].name+"="+encodeURIComponent(act)+"&";
+	    }else if(node.elements[i].name == 'file'){       
+	         var file = node.elements[i].id;
+		  if(method == 'POST')
+		    formData.append(file, file.files[0]);
 	    }else if(node.elements[i].type == 'select-multiple'){
 	       for (var j=0, len=node.elements[i].options.length; j<len; j++) {
-		var  opt = node.elements[i].options[j];
-		if ( opt.selected )
-		      url += node.elements[i].name +"="+ encodeURIComponent(node.elements[i].options[j].value)+"&";
+		  var  opt = node.elements[i].options[j];
+		  if ( opt.selected ){
+		      if(method == 'POST')
+			formData.append(node.elements[i].name,node.elements[i].options[j].value);
+		      else
+			url += node.elements[i].name +"="+ encodeURIComponent(node.elements[i].options[j].value)+"&";
+		  }
 		}
 	    }else{
-	      url += node.elements[i].name+"="+encodeURIComponent(node.elements[i].value)+"&"; 
+	      if(method == 'POST')
+		formData.append(node.elements[i].name,node.elements[i].value);
+	      else
+	      	url += node.elements[i].name+"="+encodeURIComponent(node.elements[i].value)+"&"; 
 	    }
 	  }
-	  requestURI(url,tabId,tabTitle);
-	}
+	  requestURI(url,tabId,tabTitle,bHistory,formData,method);
+
+      }
 }
 var http_request = false;
 var oldpage;
-function requestURI(url,id,txt,bHistory){
+//requestURI('%ALIAS%/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
+function requestURI(url,id,txt,bHistory,formData,method,bWaid){
 	closePopup();
+	if(txt)
+	window.document.title = txt;
 	bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
-	if(bHistory)
+	method   = typeof method   !== 'undefined' ? method   : 'GET';
+	bWaid    = typeof bWaid   !== 'undefined' ? bWaid   : true;
+	if(bHistory && method == 'GET')
 	  history.pushState(null, '','?'+url);
-	var waid = getText('animationContainer');
-	oldpage = '';
-	oldpage = getText('content');
-	var w = '<div class="waid" >'+waid+'</div>';
-	setText('content',w);
-
+	
+	if(bWaid){
+	  var waid = getText('animationContainer');
+	  oldpage = '';
+	  oldpage = getText('content');
+	  var w = '<div class="waid" >'+waid+'</div>';
+	  setText('content',w);
+	}
         http_request = false;
 
         if (window.XMLHttpRequest) { //Firefox
@@ -281,11 +310,17 @@ function requestURI(url,id,txt,bHistory){
         }
 	if($(id))
 	  setCurrentTab(id,txt);			
-	else
+	else if(txt)
 	  setCurrentTab('dynamicLink',txt);	
         http_request.onreadystatechange = setContent;
-        http_request.open('GET', url, true);
-        http_request.send(null);
+	if(method != 'POST'){
+	  http_request.open('GET', url, true);
+	  http_request.send(null);
+	}else{
+	  http_request.open('POST', "../%ALIAS%/mysql.pl?", true);
+	  http_request.setRequestHeader("Content-Type", "multipart/form-data");
+	  http_request.send(formData);
+	}
 }
 
 function loadXMLDoc(filename){
@@ -346,14 +381,7 @@ function evalId(id){
 	  }
 	}
 }
-window.onerror = logError;
-function logError(a,b,c){
-       alert(a+" "+" "+b+" "+c);
-}
-window.onerror = logError;
-function logError(a,b,c){
-       alert(a+" "+" "+b+" "+c);
-}
+
 window.onpopstate =loadHistory;
 function loadHistory(){
 	var rxObj =  new RegExp(/action=([^&]+)/);
@@ -363,12 +391,14 @@ function loadHistory(){
 	rxObj2.exec(window.location.search);
 	var uri = RegExp.$1;
 	var url = window.location.search;
-	if(uri && action)
-	  requestURI('cgi-bin/mysql.pl'+uri,action,action,false);
-	else
-	  requestURI('cgi-bin/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
+	if(uri && action){
+	   requestURI('%ALIAS%/mysql.pl'+uri,action,action,false);
+  
+	}else
+	  requestURI('%ALIAS%/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
 	return true;
 }
+
 function translate(string){
 	var lng = navigator.language.indexOf("de") > -1 ? 'de':'en';
         var l = new Lang(); 
@@ -431,7 +461,7 @@ function Autocomplete(evt){
 	  var i = 0;
 	  var j = autocomplete.length;
 	  while( i < autocomplete.length){
-		if(match.toLowerCase() == autocomplete[i].substr(0,offset)){
+		if(match == autocomplete[i].substr(0,offset)){
 		  var selectionStart = $("sqlEdit").selectionStart;
 		  var before = $("sqlEdit").value.substr(0,selectionStart-offset);
 		  var behind = $("sqlEdit").value.substr(selectionStart,$("sqlEdit").value.length);
@@ -448,7 +478,7 @@ function Autocomplete(evt){
 
 function selKeyword(id){
   for(var i= 0; i<  $(id).options.length;i++ )
-      autocomplete.push( $(id).options[i].value.toLowerCase());
+      autocomplete.push( $(id).options[i].value);
 }
 var uno = true;
 function showSQLEditor(){
@@ -491,7 +521,7 @@ function insertAtCursorPosition(txt){
 
 var timer;
 function toolbarOver(){
-    timer = setTimeout(function lol(){showToolbar('toolbar');showToolbar('toolbar2');},300)
+    timer = setTimeout(function start(){showToolbar('toolbar');showToolbar('toolbar2');},300)
 }
 
 function toolbarOut(){
@@ -527,3 +557,114 @@ function hideToolbar(id){
   }
   clearTimeout(timer);
 }
+var nCurrentRow = 0;
+function enter(event){
+  var keyCode = event.keyCode ? event.keyCode :event.charCode ? event.charCode :event.which;
+  if (keyCode == 13) 
+  return true;
+  else
+  return false;
+}
+function setAll(){
+       var body  = document.getElementsByTagName("body")[0];
+       var node = body.getElementsByTagName("option");
+       for(var i=0,j=node.length; i<j; i++)
+       if(node[i].className == 'set') 
+	 node[i].selected = true;
+}
+function editSet(input,select){
+  $(input).value = select.options[select.options.selectedIndex].value;
+  nCurrentRow = select.options.selectedIndex;
+}
+function setEnter(input,select){
+  if(!$(select).options[nCurrentRow] ){
+    addEntry(select,input.id);
+  }
+  $(select).options[nCurrentRow].value = input.value;
+  $(select).options[nCurrentRow].text = input.value;
+}
+function deleteEntry (idSelect) {
+  $(idSelect).options[$(idSelect).options.selectedIndex] = null;
+}
+function clearSelect (idSelect) {
+     $(idSelect).innerHTML ='';
+     nCurrentRow = 0;
+}
+function addEntry(idSelect,idEdit) {
+  newEntry = new Option('', '', false, true);
+  var n = $(idSelect).length;
+  $(idSelect).options[n] = newEntry;
+  $(idSelect).options[n].className ='set';
+}
+function displayTree(id){
+       var e = document.getElementById(id);
+       if(!e)return;
+       var display = e.style.display;
+       if(display == "none"){
+              e.style.display = "";
+       }else if(display == ""){
+              e.style.display = "none";
+       }
+}
+// object.x - .y =  getElementPosition(id);
+function getElementPosition(id){
+       var node = document.getElementById(id);
+       var offsetLeft = 0;
+       var offsetTop = 0;
+       while (node){
+              offsetLeft += node.offsetLeft;
+              offsetTop += node.offsetTop;
+              node = node.offsetParent;
+       }
+       var position = new Object();
+       position.x = offsetLeft;
+       position.y = offsetTop;
+       return position;
+}
+function move(id,x,y){
+       Element = document.getElementById(id);
+       Element.style.position = "absolute";
+       Element.style.left = x + "px";
+       Element.style.top  = y + "px";
+}
+var openMenu;
+function showMenu(linkId,menuId){
+       if(menuId != openMenu) hide(openMenu);
+       openMenu = menuId;
+       var oLink = document.getElementById(linkId);
+       var oMenu = document.getElementById(menuId);
+       var o = getElementPosition(linkId);
+       var ao = getWindowSize();
+       var c = (( o.x +  oLink.offsetWidth  )- oMenu.offsetWidth );
+       c = c > 0 ? c : o.x-1;
+       move(menuId,ao.x > o.x+ oMenu.offsetWidth ?  o.x-1  : c+1  ,o.y+oLink.offsetHeight );
+       displayTree(menuId);
+}
+function getWindowSize() {
+       var nWidth = 0, nHeight = 0;
+       var o = new Object;
+       if( typeof( window.innerWidth ) == 'number' ) {//Gecko
+              o.x = window.innerWidth;
+              o.y =  window.innerHeight;
+              return o;
+       } else if( document.documentElement &&  document.documentElement.clientWidth && document.documentElement.clientHeight  ) {//Ie
+              o.x = document.documentElement.clientWidth;
+              o.y = document.documentElement.clientHeight;
+              return o;
+       }
+       o.x = 0;
+       o.y = 0;
+       return o;
+}
+var pnPageY = 0;
+function scrollToTop(){
+  pnPageY =  window.pageYOffset;
+  var node = document.getElementById('topUp');
+  window.setTimeout(pageUp,1);
+}
+ function pageUp(){
+	pnPageY-=250;
+	window.scrollTo(0,pnPageY);
+	if(pnPageY > 0)
+	window.setTimeout(pageUp,1);
+}
