@@ -2,8 +2,23 @@ package DBI::Library;
 use strict;
 use warnings;
 use utf8;
-use vars
-    qw( $m_dbh $m_dsn $m_sDefaultClass $m_hrSettings  @EXPORT_OK @ISA %m_hFunctions $m_sStyle $m_nRight $m_tbl $driver $m_oDatabase $m_sHost $m_sPass $m_sUser);
+use vars qw( 
+$m_dbh 
+$m_dsn 
+$m_sDefaultClass 
+$m_hrSettings  
+@EXPORT_OK 
+@ISA 
+%m_hFunctions 
+$m_sStyle 
+$m_nRight 
+$m_tbl 
+$driver 
+$m_oDatabase 
+$m_sHost 
+$m_sPass 
+$m_sUser
+);
 $m_sDefaultClass = 'DBI::Library' unless defined $DBI::Library::m_sDefaultClass;
 @DBI::Library::EXPORT_OK
     = qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver  useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists initDB $m_dsn $m_dbh selectTable);
@@ -18,7 +33,7 @@ $m_sDefaultClass = 'DBI::Library' unless defined $DBI::Library::m_sDefaultClass;
         qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
     ],
 );
-$DBI::Library::VERSION = '0.75';
+$DBI::Library::VERSION = '0.76';
 $m_tbl                 = 'querys';
 $driver                = 'mysql';
 require Exporter;
