@@ -19,19 +19,19 @@ use DBI::Library qw(:all $m_dbh $m_dsn);
 @DBI::Library::Database::ISA    = qw(DBI::Library Exporter);
 @DBI::Library::Database::EXPORT = qw(useexecute);
 @DBI::Library::Database::EXPORT_OK =
-  qw(getIndex getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists addUser hasAcount isMember right getAction checkPass checkSession setSid getName initDB checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
+  qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists addUser hasAcount isMember right checkPass checkSession setSid getName initDB checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
 %DBI::Library::Database::EXPORT_TAGS = (
     'all' => [
-        qw(getIndex getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right getAction checkPass checkSession setSid getName initDB tableLength tableExists useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)
+        qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName initDB tableLength tableExists useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)
     ],
-    'dynamic' => [qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute)],
+    'dynamic' => [qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute)],
     'independent' =>
-      [qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute fetch_string)],
+      [qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute fetch_string)],
     'lze' => [
-        qw(getIndex getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right getAction checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
+        qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
     ],
 );
-$DBI::Library::Database::VERSION = '0.75';
+$DBI::Library::Database::VERSION = '0.76';
 $m_nSecs                         = 10;
 
 =head1 NAME
@@ -153,42 +153,6 @@ sub checkPass
     return 0;
 }
 
-=head2 getAction
-
-      $hashref = $m_oDatabase->getAction($m_sAction);
-
-=cut
-
-sub getAction
-{
-    my ($self, @p) = getSelf(@_);
-    my $m_sAction = $p[0];
-    my $sql       = q/select * from actions where action = ?/;
-    my $sth       = $m_dbh->prepare($sql) or warn $m_dbh->errstr;
-    $sth->execute($m_sAction);
-    my $hr = $sth->fetchrow_hashref;
-    $sth->finish();
-    return $hr;
-}
-
-=head2 getActionRight
-
-      $right = $m_oDatabase->getActionRight($m_sAction);
-
-=cut
-
-sub getActionRight
-{
-    my ($self, @p) = getSelf(@_);
-    my $m_sAction = $p[0];
-    my $sql       = q/select `right` from actions where action = ?/;
-    my $sth       = $m_dbh->prepare($sql) or warn $m_dbh->errstr;
-    $sth->execute($m_sAction);
-    my $hr = $sth->fetchrow_array;
-    $sth->finish();
-    return $hr;
-}
-
 =head2 right()
 
       $nRight = right($m_sAction,$m_sUsername);
@@ -462,6 +426,7 @@ sub getIndex
     }
 }
 
+   
 =head2 GetAutoIncrement()
 
        liefert die auto_increment zeile zurueck
@@ -524,24 +489,6 @@ sub GetDataBases
     return $return;
 }
 
-=head2 GetTables()
-
-        GetTables(name,selected )
-
-=cut
-
-sub GetTables
-{
-    my ($self, @p) = getSelf(@_);
-    my $name     = $p[0] ? shift : 'm_ChangeCurrentDb';
-    my $selected = $p[0] ? shift : '';
-    my @tbl      = $self->fetch_array('show Tables');
-    my $return   = qq|<select align="left" name="$name"  >|;
-    $return .= qq|<option  value="$_"  | . ($_ eq $selected ? 'selected="selected"' : '') . qq|>$_</option>| foreach @tbl;
-    $return .= '</select>';
-    return $return;
-}
-
 =head2 TableCount4Db()
 
      Gibt die anzahl der tabellen fuer die angegebene Datenbank zurueck.
@@ -593,7 +540,7 @@ sub GetEngines
     if (defined $tbl) {
         my @co     = $self->fetch_AoH('SHOW ENGINES');
         my $status = $self->fetch_hashref('SHOW TABLE STATUS where `Name` = ? ', $tbl);
-        my $return = qq|<select class="ediTable" name="$name">|;
+        my $return = qq|<select class="editTable" name="$name">|;
         $return .=
           $_->{Engine} eq $status->{Engine}
           ? qq|<option  value="$_->{Engine}"  selected="selected" >$_->{Engine}</option>|
@@ -620,7 +567,7 @@ sub GetEngineForRow
     if (defined $tbl && defined $name) {
         my @co       = $self->fetch_array('SHOW ENGINES');
         my @EINGINES = $self->fetch_AoH('SHOW TABLE STATUS where `Name` = ?  ', $tbl);
-        my $return   = qq|<select class="ediTable" name="$name">|;
+        my $return   = qq|<select class="editTable" name="$name">|;
         $return .=
           $_->{Engine} eq "@co"
           ? qq|<option  value="$_->{Engine}"  selected="selected" >$_->{Engine}</option>|
@@ -647,7 +594,7 @@ sub GetNull
     my $null = shift @p;
     my $name = shift @p;
     if (defined $null && defined $name) {
-        my $return = qq|<select class="ediTable" name="$name">|;
+        my $return = qq|<select class="editTable" name="$name">|;
         $return .= qq|<option  value="not NULL">not NULL</option>|;
         $return .=
           $null eq 'YES'
@@ -674,7 +621,7 @@ sub GetExtra
     my $selected = shift @p;
     my $name     = shift @p;
     if (defined $selected && defined $name) {
-        my $return = qq|<select class="ediTable" name="$name">|;
+        my $return = qq|<select class="editTable" name="$name">|;
         $return .= '<option value=""></option>';
         $return .=
           $selected eq "auto_increment"
@@ -687,106 +634,6 @@ sub GetExtra
     }
 }
 
-=head2 GetTypes()
-
-        gibt die datentypen zurueck
-
-        GetTypes(selected type, slect_name);
-
-=cut
-
-sub GetTypes
-{
-    my ($self, @p) = getSelf(@_);
-    my $type = shift @p;
-    my $name = shift @p;
-    $type =~ s/(\w+).*/uc $1/eg;
-    if (defined $type && defined $name) {    #todo title setzen
-        my $return = qq|<select class="ediTable" name="$name">|;
-        $return .= '<option></option>';
-        $return .=
-          $type eq 'TINYINT'
-          ? '<option  value="TINYINT"  selected="selected" >TINYINT</option>'
-          : '<option  value="TINYINT" >TINYINT</option>';
-        $return .=
-          $type eq 'SMALLINT'
-          ? '<option selected="selected"  value="SMALLINT" >SMALLINT</option>'
-          : '<option value="SMALLINT" >SMALLINT</option>';
-        $return .=
-          $type eq 'MEDIUMINT'
-          ? '<option selected="selected"  value="MEDIUMINT" >MEDIUMINT</option>'
-          : '<option value="MEDIUMINT" >MEDIUMINT</option>';
-        $return .=
-          $type eq 'INT'
-          ? '<option selected="selected"  value="INT" >INT</option>'
-          : '<option value="INT" >INT</option>';
-        $return .=
-          $type eq 'BIGINT'
-          ? '<option selected="selected"  value="BIGINT" >BIGINT</option>'
-          : '<option value="BIGINT" >BIGINT</option>';
-        $return .=
-          $type eq 'FLOAT'
-          ? '<option selected="selected"  value="FLOAT" >FLOAT</option>'
-          : '<option value="FLOAT" >FLOAT</option>';
-        $return .=
-          $type eq 'DOUBLE'
-          ? '<option selected="selected"  value="DOUBLE" >DOUBLE</option>'
-          : '<option value="DOUBLE" >DOUBLE</option>';
-        $return .=
-          $type eq 'DECIMAL'
-          ? '<option selected="selected"  value="DECIMAL" >DECIMAL</option>'
-          : '<option value="DECIMAL" >DECIMAL</option>';
-        $return .=
-          $type eq 'DATE'
-          ? '<option selected="selected"  value="DATE" >DATE</option>'
-          : '<option value="DATE">DATE</option>';
-        $return .=
-          $type eq 'DATETIME'
-          ? '<option selected="selected"  value="DATETIME" >DATETIME</option>'
-          : '<option value="DATETIME" >DATETIME</option>';
-        $return .=
-          $type eq 'TIMESTAMP'
-          ? '<option selected="selected"  value="TIMESTAMP" >TIMESTAMP</option>'
-          : '<option value="TIMESTAMP" >TIMESTAMP</option>';
-        $return .=
-          $type eq 'TIME'
-          ? '<option selected="selected"  value="TIME" >TIME</option>'
-          : '<option value="TIME" >TIME</option>';
-        $return .=
-          $type eq 'YEAR'
-          ? '<option selected="selected"  value="YEAR" >YEAR</option>'
-          : '<option value="YEAR"  >YEAR</option>';
-        $return .=
-          $type eq 'CHAR'
-          ? '<option selected="selected"  value="CHAR" >CHAR</option>'
-          : '<option value="CHAR" >CHAR</option>';
-        $return .=
-          $type eq 'VARCHAR'
-          ? '<option selected="selected"  value="VARCHAR" >VARCHAR</option>'
-          : '<option value="VARCHAR">VARCHAR</option>';
-        $return .=
-          $type eq 'BLOB'
-          ? '<option selected="selected"  value="BLOB" >BLOB</option>'
-          : '<option value="BLOB" >BLOB</option>';
-        $return .=
-          $type eq 'TEXT'
-          ? '<option selected="selected"  value="TEXT" >TEXT</option>'
-          : '<option value="TEXT"  >TEXT</option>';
-        $return .=
-          $type eq 'ENUM'
-          ? '<option selected="selected"  value="ENUM" >ENUM</option>'
-          : '<option value="ENUM"  >ENUM</option>';
-        $return .=
-          $type eq 'SET'
-          ? '<option selected="selected"  value="SET" >SET</option>'
-          : '<option value="SET">SET</option>';
-        $return .= '</select>';
-        return $return;#todo datentyp setzen
-    } else {
-        return 0;
-    }
-}
-
 =head2 GetColumnCollation()
 
        gibt eine auswahlliste (select) zurueck.
@@ -805,7 +652,7 @@ sub GetColumnCollation
         $tbl = $m_dbh->quote_identifier($tbl);
         my $col       = $self->fetch_hashref("show full columns from $tbl where field = ?", $column);
         my @collation = $self->fetch_AoH("SHOW COLLATION");
-        my $return    = qq|<select class="ediTable" name="$name" style="width:100px;"><option></option>|;
+        my $return    = qq|<select class="editTable" name="$name" style="width:100px;"><option></option>|;
         unless ($col->{Collation}) {
             $return .= qq|<option  value="NULL"  selected="selected" >NULL</option>|;
         } else {
@@ -841,7 +688,7 @@ sub GetCollation
             $selected = $a[$i]->{Collation} if ($a[$i]->{Name} eq $selected);
         }
     }
-    my $return = qq|<select class="ediTable" name="$name" style="width:100px;"><option></option>|;
+    my $return = qq|<select class="editTable" name="$name" style="width:100px;"><option></option>|;
     $return .= qq|<option  value="$_->{Collation}"| . ($selected eq $_->{Collation} ? 'selected="selected"' : '') . qq|>$_->{Collation}</option>| foreach @collation;
     $return .= '</select>';
     return $return;
@@ -866,7 +713,7 @@ sub GetCharset
         }
         }
         $selected = GetCharacterSet($selected );
-    my $return = qq|<select class="ediTable" name="$name" style="width:100px;"><option></option>|;
+    my $return = qq|<select class="editTable" name="$name" style="width:100px;"><option></option>|;
     $return .= qq|<option  value="$_->{Charset}"| . ($selected eq $_->{Charset} ? 'selected="selected"' : '') . qq|>$_->{Charset}</option>| foreach @Charset;
     $return .= '</select>';
     return $return;
@@ -885,8 +732,9 @@ sub GetAttrs
     my $select = shift @p;
     my $name   = shift @p;
     if ($tbl) {
+	 $tbl    = $m_dbh->quote_identifier($tbl);
         my $hr     = $self->fetch_hashref("SHOW CREATE TABLE $tbl");
-        my $return = qq|<select class="ediTable" name="$name" style="width:100px;">
+        my $return = qq|<select class="editTable" name="$name" style="width:100px;">
     <option ></option>
     <option  value="UNSIGNED" |
           . (
@@ -912,7 +760,7 @@ sub GetAttrs
         return $return;
     } else {
         return qq(
-    <select class="ediTable" name="$name" style="width:100px;">
+    <select class="editTable" name="$name" style="width:100px;">
     <option ></option>
     <option  value="UNSIGNED" ) .                    ($select eq 'UNSIGNED'                    ? 'selected="selected"' : '') . q(>UNSIGNED</option>
     <option  value="UNSIGNED ZEROFILL" ) .           ($select eq 'UNSIGNED ZEROFILL'           ? 'selected="selected"' : '') . q(>UNSIGNED ZEROFILL</option>
@@ -932,9 +780,10 @@ sub GetColumns
     my ($self, @p) = getSelf(@_);
     my $tbl      = shift @p;
     my $name     = shift @p;
-    my $selected = shift @p;
+    my $selected = $p[0] ? shift @p : '';
+    $tbl =$m_dbh->quote_identifier($tbl);
     my @col      = $self->fetch_AoH("show columns from $tbl");
-    my $return   = qq|<select class="ediTable" name="$name" style="width:100px;">|;
+    my $return   = qq|<select class="editTable" name="$name" style="width:100px;">|;
     $return .= qq|<option  value="$_->{Field}" | . ($selected eq $_->{Field} ? 'selected="selected"' : '') . qq|>$_->{Field}</option>| foreach @col;
     $return .= '</select>';
     return $return;
