@@ -15,7 +15,7 @@ use Encode;
 use Fcntl qw(:flock);
 use Symbol;
 use URI::Escape;
-
+# use diagnostics;
 # use CGI::Carp qw(fatalsToBrowser);
 require Exporter;
 use vars qw(
@@ -23,43 +23,36 @@ use vars qw(
   $ACCEPT_LANGUAGE
   @EXPORT
   @ISA
-  @m_aCookies
   $m_bMod_perl
   %m_hUniq
-  $m_hrAct
   $m_hrParams
   $m_hrSettings
   $m_hrLng
   $m_nStart
   $m_nEnd
   $m_nRight
-  $m_nSize
   $m_oDatabase
   $m_dbh
   $m_sAction
-  $m_sFile
   $m_sSid
   $m_sStyle
-  $m_sSub
   $m_sTitle
   $m_sUser
   $m_sContent
-  $m_hContent
   $m_sCurrentDb
   $m_sCurrentHost
   $m_sCurrentUser
   $m_sCurrentPass
   $m_sAjax
   $m_nSkipCaptch
-  $m_hrLng
 );
 @MySQL::Admin::GUI::EXPORT  = qw(ContentHeader Body ChangeDb Unique);
 @ISA                        = qw(Exporter MySQL::Admin);
-$MySQL::Admin::GUI::VERSION = '0.75';
+$MySQL::Admin::GUI::VERSION = '0.76';
 $m_bMod_perl                = ( $ENV{MOD_PERL} ) ? 1 : 0;
 local $^W = 0;
-$m_sAjax = qq(<?xml version="1.0" encoding="UTF-8"?>\n<xml>);
-$m_nSkipCaptch = 0;
+
+
 =head1 NAME
 
 MySQL::Admin::GUI - Just a MySQL administration Web-App
@@ -86,10 +79,12 @@ MySQL::Admin::GUI - Just a MySQL administration Web-App
 sub ContentHeader {
     my $m_hrSettingsfile = shift;
     init($m_hrSettingsfile);
+    
+    $m_sAjax = qq(<?xml version="1.0" encoding="UTF-8"?>\n<xml>);
+    $m_nSkipCaptch = 0;
     #todo klären wiso m_hrLng durch init() nicht gesetzt wird.
-#     *m_hrLng = \$MySQL::Admin::Translate::lang;
+    *m_hrLng = \$MySQL::Admin::Translate::lang;
     $m_oDatabase = new DBI::Library::Database();
-    $m_oDatabase->rewrite( $m_hrSettings->{cgi}{mod_rewrite} );
     $m_oDatabase->serverName( $m_hrSettings->{cgi}{serverName} );
     $m_oDatabase->floodtime( $m_hrSettings->{floodtime} );
     $m_dbh = $m_oDatabase->initDB(
@@ -104,13 +99,12 @@ sub ContentHeader {
         param('m_ChangeCurrentDb')
       ? param('m_ChangeCurrentDb')
       : $m_hrSettings->{database}{CurrentDb};
-    $m_sAction =
-      param('action') ? param('action') : $m_hrSettings->{defaultAction};
+    $m_sAction =  param('action') ? param('action') : 'ShowDatabases';#todo settings
 
     $m_sAction =
       ( $m_sAction =~ /^(\w{3,50})$/ )
       ? $1
-      : $m_hrSettings->{defaultAction};
+      : $m_sAction;
     $m_sCurrentHost =
         param('m_shost')
       ? param('m_shost')
@@ -134,34 +128,29 @@ sub ContentHeader {
     }
     my $cookiepath = $m_hrSettings->{cgi}{cookiePath};
 
-    $m_sSid = cookie( -name => 'sid' ) ? cookie( -name => 'sid' ) : '123';
-
-  $m_sUser =
-      defined $m_oDatabase->getName($m_sSid)
-      ? $m_oDatabase->getName($m_sSid)
-      : 'guest';
-    if ( $m_sAction eq 'logout' or  ($m_sAction ne 'login' and $m_sUser eq 'guest') ) {
+    $m_sSid = cookie( -name => 'sid' );
+    $m_sSid = defined $m_sSid ? $m_sSid : '123';
+    $m_sUser = $m_oDatabase->getName($m_sSid);
+    $m_sUser = defined $m_sUser ? $m_sUser : 'guest';
+    my @aCookies;
+    if ( $m_sAction eq 'logout'  or ($m_sUser  eq 'guest' and  $m_sAction ne 'login') ) {
         my $cookie = cookie(
             -name    => 'sid',
             -value   => '',
             -expires => '-1d',
             -path    => "$cookiepath"
         );
-        $m_sAjax .=
-            '<output id="login"><![CDATA['
-          . do('$m_hrSettings->{cgi}{bin}/Sidebar/exploit.pl')
-          . ']]></output>';
-        push @m_aCookies, $cookie;
+        push @aCookies, $cookie;
         print header(
             -type    => 'text/xml',
             -charset => 'UTF-8',
-            -cookie  => [@m_aCookies]
+            -cookie  => [@aCookies]
         );
         $m_sUser   = 'guest';
         $m_sSid    = '123';
         $m_sAction = 'showLogin';
-    }
-    elsif ( $m_sAction eq 'login' ) {
+
+    }elsif ( $m_sAction eq 'login') {
         my $ip = remote_addr();
         my $u  = param('user');
         my $p  = param('pass');
@@ -189,19 +178,18 @@ sub ContentHeader {
                     -path    => "$cookiepath",
                     -expires => '+1y'
                 );
-                push @m_aCookies, $cookie if $result eq 1;
+                push @aCookies, $cookie if $result eq 1;
                 print header(
                     -type    => 'text/xml',
                     -charset => 'UTF-8',
-                    -cookie  => [@m_aCookies]
+                    -cookie  => [@aCookies]
                 );
-
+		 $m_sUser = $u;
             }
             else {
                 print header(
                     -type    => 'text/xml',
                     -charset => 'UTF-8',
-                    -cookie  => [@m_aCookies]
                 );
             }
         }
@@ -209,16 +197,13 @@ sub ContentHeader {
             print header(
                 -type    => 'text/xml',
                 -charset => 'UTF-8',
-                -cookie  => [@m_aCookies]
             );
         }
         $m_sAction = 'ShowDatabases';
-    }
-    else {
+    }else {
         print header(
             -type    => 'text/xml',
-            -charset => 'UTF-8',
-            -cookie  => [@m_aCookies]
+            -charset => 'UTF-8'
         );
     }
 }
@@ -231,120 +216,49 @@ sub ContentHeader {
 
 sub Body {
     $m_sStyle = $m_hrSettings->{cgi}{style};
-    $m_sUser =
-      defined $m_oDatabase->getName($m_sSid)
-      ? $m_oDatabase->getName($m_sSid)
-      : 'guest';
+
     $m_nStart = param('von')               ? param('von') : 0;
     $m_nStart = ( $m_nStart =~ /^(\d+)$/ ) ? $1           : 0;
-    $m_nEnd   = param('bis')               ? param('bis') : 10;
+    $m_nEnd   = param('bis')               ? param('bis') : 30;
     $m_nEnd   = ( $m_nEnd =~ /^(\d+)$/ )   ? $1           : 0;
-    if ( $m_nStart < 0 ) {
+    if ( $m_nStart < 0 ){
         $m_sAction = 'exploit';
         $m_nStart  = 0;
     }
-
-    $m_hrAct = $m_oDatabase->getAction($m_sAction);
-
-    $m_hrAct =
-      defined $m_hrAct
-      ? $m_hrAct
-      : $m_oDatabase->getAction( $m_hrSettings->{'defaultAction'} );
-    $m_sTitle = $m_hrAct->{title};
-    $m_sFile  = $m_hrAct->{file};
-    $m_sSub   = $m_hrAct->{sub};
-    $m_nRight =
-        $m_oDatabase->userright($m_sUser)
-      ? $m_oDatabase->userright($m_sUser)
-      : 0;
-
-
-    if ( defined $m_hrAct->{box} ) {
-
-        my @boxes = split / /, $m_hrAct->{box};
-        foreach my $box (@boxes) {
-            $m_sContent = "";
-            my $bx = $m_oDatabase->fetch_hashref(
-                "select * from box where `file` = ? && `right` <= ? ",
-                "$box.pl", $m_nRight );
-            do("$m_hrSettings->{cgi}{bin}/Sidebar/$bx->{file}")
-              if ( defined $bx->{file}
-                && -e "$m_hrSettings->{cgi}{bin}/Sidebar/$bx->{file}" );
-            $m_sAjax .= "<output id=\"errorMessage\"><![CDATA[$@]]></output>"
-              if ($@);
-            $m_sAjax .=
-                "<output id=\"$bx->{outId}\"><![CDATA["
-              . $m_sContent
-              . ']]></output>'
-              if $m_sContent;
-            $m_sContent = "";
-        }
+    $m_nRight = $m_oDatabase->userright($m_sUser);
+    $m_nRight  = defined $m_nRight ? $m_nRight: 0;
+    my $exploit = 0;
+    my @action_set = $m_oDatabase->fetch_AoH("select actions.action,actions.file,actions.title,actions.right,actions.sub,actions_set.output_id from actions join actions_set on actions.action = actions_set.foreign_action where actions_set.action = ?",$m_sAction);
+    $exploit = 1 if $@;
+    for( my $i = 0; $i <= $#action_set;$i++) {
+	$m_sContent = "";
+	my $action = $action_set[$i];
+	$m_sTitle = $action->{title};
+	if ( $m_nRight >= $action->{right} ){
+	  do("$m_hrSettings->{cgi}{bin}/Content/$action->{file}") if  -e "$m_hrSettings->{cgi}{bin}/Content/$action->{file}";
+	  eval($action->{sub}) if $action->{sub} ne 'main';
+	  $m_sAjax .= qq|<output id="errorMessage"><![CDATA[$@]]></output>| if $@;
+	  $m_sAjax .= qq|<output id="$action->{output_id}"><![CDATA[$m_sContent]]></output>|;
+	}else{
+	  $exploit = 1;
+	}
     }
-    if(param('include')){
-      include(param('include'));
-    }else{
-      do("$m_hrSettings->{cgi}{bin}/Sidebar/exploit.pl");
-    }
-    $m_sAjax .= '<output id="login"><![CDATA[' . $m_sContent . ']]></output>';
-    $m_sContent = '';
-
-    if ( $m_nRight >= $m_hrAct->{right} ) {
-        if ( defined $m_sFile and defined $m_sSub ) {
-            $m_sContent = "";
-            do("$m_hrSettings->{cgi}{bin}/Content/$m_sFile");
-            eval($m_sSub) if $m_sSub ne 'main';
-            if ($@) {
-                $m_sAjax .=
-                  '<output id="content"><![CDATA[' . $@ . ']]></output>';
-            }
-            else {
-                $m_sAjax .=
-                    '<output id="content"><![CDATA['
-                  . $m_sContent
-                  . ']]></output>';
-            }
-            $m_dbh = $m_oDatabase->initDB(
-                {
-                    name     => $m_hrSettings->{database}{name},
-                    host     => $m_hrSettings->{database}{host},
-                    user     => $m_hrSettings->{database}{user},
-                    password => $m_hrSettings->{database}{password},
-                }
-            );
-
-        }
-        else {
-            $m_sContent = "";
-            do("$m_hrSettings->{cgi}{bin}/Content/exploit.pl");
-
-            #eval($m_sSub) if $m_sSub ne 'main';
-            if ($@) {
-                $m_sAjax .=
-                  '<output id="content"><![CDATA[' . $@ . ']]></output>';
-            }
-            else {
-                $m_sAjax .=
-                    '<output id="content"><![CDATA['
-                  . $m_sContent
-                  . ']]></output>';
-            }
-        }
-    }
-    else {
+    if($exploit) {
         $m_sContent = "";
         do("$m_hrSettings->{cgi}{bin}/Content/exploit.pl");
-        if ($@) {
-            $m_sAjax .= '<output id="content"><![CDATA[' . $@ . ']]></output>';
-        }
-        else {
-            $m_sAjax .=
-              '<output id="content"><![CDATA[' . $m_sContent . ']]></output>';
-        }
+        $m_sAjax .= qq|<output id="errorMessage"><![CDATA[$@]]></output>| if $@;
+        $m_sAjax .= qq|<output id="content"><![CDATA[$m_sContent]]></output>| if $m_sContent;
+    }else{#change main Db
+	ChangeDb(
+	    {   name     => $m_hrSettings->{database}{name},
+		host     => $m_hrSettings->{database}{host},
+		user     => $m_hrSettings->{database}{user},
+		password => $m_hrSettings->{database}{password},
+	    }
+	);
     }
-
-    $m_sContent .= '</tr></table>';
     clearSession();
-    return $m_sAjax . "</xml>";
+    return $m_sAjax . '</xml>';
 }
 
 =head2 ChangeDb
